@@ -165,7 +165,7 @@ class NlpClient(AbstractClient):
 
 
     def GenerateKeywordSentence(self, request):
-        """提取文本中的关键信息，生成简洁明了的关键句子，便于用户快速获取核心观点。
+        """根据提供的关键词，生成简洁明了的关键句子，便于用户快速获取核心观点。
 
         :param request: Request instance for GenerateKeywordSentence.
         :type request: :class:`tencentcloud.nlp.v20190408.models.GenerateKeywordSentenceRequest`
@@ -257,7 +257,9 @@ class NlpClient(AbstractClient):
 
 
     def TestingTextGeneration(self, request):
-        """基于腾讯大模型能力，用户可以通过传入不同的参数控制生成内容的类型，并通过自然语言给模型以内容生成的指令，可以满足多种场景的文本生成需求，包括但不限于文章写作、营销文案、视频脚本、电商文案、纪要整理等（注意：当前接口为内测体验专用接口，非正式服务接口，内测期结束接口会下线或停服，届时请接入正式服务接口）
+        """文案创作（内测版）为内测体验专用接口，现内测期结束，统一改为使用正式服务接口（混元大模型），故内测接口做下线处理。
+
+        基于腾讯大模型能力，用户可以通过传入不同的参数控制生成内容的类型，并通过自然语言给模型以内容生成的指令，可以满足多种场景的文本生成需求，包括但不限于文章写作、营销文案、视频脚本、电商文案、纪要整理等（**注意：当前接口为内测体验专用接口，仅有获取白名单权限的客户可以测试调用，如需测试请联系商务非正式服务接口，内测期结束接口会下线或停服，届时请接入正式服务接口**）
 
         :param request: Request instance for TestingTextGeneration.
         :type request: :class:`tencentcloud.nlp.v20190408.models.TestingTextGenerationRequest`
